==> miaow-3.5.1.tgz: package/lib/config/index.js <==
var _ = require('lodash');
var async = require('async');
var fs = require('fs');
var mutil = require('miaow-util');
var path = require('path');

// 默认配置
var defaultConfig = require('./default');

module.exports = function (options) {
  options = options || {};

  var environment = options.environment || 'default';

  var configList;

  try {
    var configPathList = [];

    if (options.configPath) {
      configPathList.push(path.resolve(process.cwd(), options.configPath));
    }

    if (options.cwd) {
      configPathList.push(path.resolve(options.cwd, 'miaow.config.js'));
    }

    configPathList.push(path.resolve(process.cwd(), 'miaow.config.js'));

    var configPath = _.find(configPathList, fs.existsSync);

    // 尝试读取用户配置
    if (configPath) {
      configList = require(configPath);
      configList = _.isArray(configList) ? configList : [configList];
      mutil.log('使用的配置路径: ' + configPath);
    } else {
      configList = [defaultConfig];
      mutil.log('使用默认配置');
    }
  } catch (err) {
    console.error('读取配置信息出错');
    console.error(err.toString());
    process.exit(1);
    return;
  }

  var config = _.find(configList, {environment: environment});

  if (!config) {
    if (environment === 'default') {
      config = configList[0];
    } else {
      throw new Error('查不到运行环境为 ' + environment + ' 的配置信息.');
    }
  }

  return _.extend({}, defaultConfig, config, _.pick(options, function (option, key) {
    return key !== 'environment' && key !== 'configPath';
  }));
};

==> miaow-4.3.0.tgz: package/lib/config/index.js <==
var _ = require('lodash');
var fs = require('fs');
var mutil = require('miaow-util');
var path = require('path');

// 默认配置
var defaultConfig = require('./default');

function getConfig(options) {
  options = options || {};

  var environment = options.environment || 'default';

  var configList;

  try {
    var configPathList = [];

    if (options.configPath) {
      configPathList.push(path.resolve(process.cwd(), options.configPath));
    }

    if (options.cwd) {
      configPathList.push(path.resolve(options.cwd, 'miaow.config.js'));
    }

    configPathList.push(path.resolve(process.cwd(), 'miaow.config.js'));

    var configPath = _.find(configPathList, fs.existsSync);

    // 尝试读取用户配置
    if (configPath) {
      configList = require(configPath);
      configList = _.isArray(configList) ? configList : [configList];
      mutil.log('使用的配置路径: ' + configPath);
    } else {
      configList = [defaultConfig];
      mutil.log('使用默认配置');
    }
  } catch (err) {
    console.error('读取配置信息出错');
    console.error(err.toString());
    process.exit(1);
    return;
  }

  var config = _.find(configList, {environment: environment});

  if (!config) {
    if (environment === 'default') {
      config = configList[0];
    } else {
      throw new Error('查不到运行环境为 ' + environment + ' 的配置信息.');
    }
  }

  config = _.extend({}, defaultConfig, config, _.pick(options, function (option, key) {
    return key !== 'environment' && key !== 'configPath';
  }));

  _.each(config.module.tasks, function (task, index) {
    if (_.isString(task)) {
      config.module.tasks[index] = config.module.taskMap[task];
    }
  });

  return config;
}

module.exports = {
  getInstance: getConfig
};
